# --------------------------------------------------------------------------- #
# Copyright (c) 2021 MOVINDOT ART S.R.L. (movindot.com). All rights reserved. #
# See eula.txt in the project root for license information.                   #
# --------------------------------------------------------------------------- #

"""The Animator's rig control dynamics UI."""

import PySide2.QtWidgets as qtw
import PySide2.QtGui as qtg
import puppeteer.ui as ui
import puppeteer.dynamics as dynamics


def createRigControlDynamicsUI(state):
    """Create the UI for the selected rig controls' dynamics."""
    with ui.GroupVBox('Dynamic Overlap', collapsed=True):
        if state.selectedRigControl.particle:
            with qtw.QFormLayout() as formLayout:
                strengthField = qtw.QLineEdit()
                strengthField.setValidator(qtg.QDoubleValidator())
                ui.bind(
                    strengthField,
                    state.selectedRigControl.particle.shapes[0],
                    'goalSmoothness',
                )

                formLayout.addRow('Strength:', strengthField)

        with qtw.QPushButton('Create') as btn:
            ui.bindInvisibility(btn, state.selectedRigControl, 'particle')
            btn.clicked.connect(
                lambda: dynamics.convertControlToParticle(state.selectedRigControl.obj)
            )

        with qtw.QPushButton('Bake') as btn:
            ui.bindVisibility(btn, state.selectedRigControl, 'particle')
            btn.clicked.connect(lambda: dynamics.bakeControlParticle(state.selectedRigControl.obj))
