# --------------------------------------------------------------------------- #
# Copyright (c) 2021 MOVINDOT ART S.R.L. (movindot.com). All rights reserved. #
# See eula.txt in the project root for license information.                   #
# --------------------------------------------------------------------------- #

"""The Animator's rig control properties UI."""

import PySide2.QtWidgets as qtw
import PySide2.QtGui as qtg
import puppeteer.rigcontrol as rigcontrol
import puppeteer.ui as ui


def createRigControlPropertiesUI(state):
    """Create the UI for the selected rig controls' properties."""
    with ui.GroupVBox('Properties', collapsed=True):
        with qtw.QFormLayout() as formLayout:
            targetField = ui.NodeField(hasPickButton=False)
            targetField.setNode(state.selectedRigControl.obj.target)

            sizeField = qtw.QLineEdit()
            sizeValidator = qtg.QDoubleValidator()
            sizeValidator.setBottom(0)
            sizeValidator.setDecimals(3)
            sizeField.setValidator(sizeValidator)

            opacityField = qtw.QLineEdit()
            opacityField.setValidator(qtg.QDoubleValidator(0, 1, 3))

            colorField = ui.ColorField(renderingSpace=True)

            xrayField = qtw.QCheckBox('X-Ray')

            for control in reversed(rigcontrol.getSelectedControls()):
                # reversed to show the values from the first selected rig control
                ui.bind(sizeField, control, 'size', lambda value: round(value, 3))
                ui.bind(opacityField, control, 'opacity', lambda value: round(value, 3))
                ui.bind(colorField, control, 'color')
                ui.bind(xrayField, control, 'xray')

            formLayout.addRow('Target', targetField)
            formLayout.addRow('Size', sizeField)
            formLayout.addRow('Opacity', opacityField)
            formLayout.addRow('Color', colorField)
            formLayout.addRow('', xrayField)  # empty label to use CheckBox's text
