# --------------------------------------------------------------------------- #
# Copyright (c) 2021 MOVINDOT ART S.R.L. (movindot.com). All rights reserved. #
# See eula.txt in the project root for license information.                   #
# --------------------------------------------------------------------------- #

"""Decorators."""

import functools
import maya.cmds as cmds


def undoable(func):
    """Allow an entire function/method to be undoed."""

    @functools.wraps(func)
    def funcWrapper(*args, **kwargs):
        try:
            cmds.undoInfo(openChunk=True, chunkName=func.__name__)
            return func(*args, **kwargs)
        finally:
            cmds.undoInfo(closeChunk=True, chunkName=func.__name__)

    return funcWrapper
