# --------------------------------------------------------------------------- #
# Copyright (c) 2021 MOVINDOT ART S.R.L. (movindot.com). All rights reserved. #
# See eula.txt in the project root for license information.                   #
# --------------------------------------------------------------------------- #

"""Settings functionality."""

import os
import PySide2.QtCore as qt


FILENAME = os.path.join(os.path.dirname(os.path.realpath(__file__)), '..', '..', 'settings.ini')


def _qtSettings():
    return qt.QSettings(FILENAME, qt.QSettings.IniFormat)


def setValue(key, value):
    """Set the value of setting key."""
    if isinstance(value, bool):
        _qtSettings().setValue(key, int(value))
    else:
        _qtSettings().setValue(key, value)

    _qtSettings().sync()


def getValue(key, defaultValue=''):
    """Get the value of setting key."""
    value = _qtSettings().value(key)

    if value is None:
        # Do this because QSettings.value() returns None if value/defaultValue is 0.
        # Fixed in 5.13.2?
        value = defaultValue

    return value


def getInt(key, defaultValue=0):
    """Get the setting as an integer."""
    return int(getValue(key, defaultValue))


def getBool(key, defaultValue=False):
    """Get the setting as a bool."""
    return bool(getInt(key, int(defaultValue)))


def clear():
    """Remove all entries."""
    _qtSettings().clear()
