# --------------------------------------------------------------------------- #
# Copyright (c) 2021 MOVINDOT ART S.R.L. (movindot.com). All rights reserved. #
# See eula.txt in the project root for license information.                   #
# --------------------------------------------------------------------------- #

"""The UI for managing settings."""

import PySide2.QtWidgets as qtw

import puppeteer.ui as ui
import puppeteer.settings as settings


class MainWindow(ui.SingletonWindow):
    """Settings main window."""

    WINDOW_TITLE = 'Settings - Puppeteer'

    def __init__(self):
        super().__init__('Settings')

        self.setMinimumWidth(600)

        mainLayout = qtw.QVBoxLayout()
        formLayout = qtw.QFormLayout()
        mainLayout.addLayout(formLayout)
        self.setLayout(mainLayout)

        self.hotReloadExtraPathField = qtw.QLineEdit()
        self.hotReloadExtraPathField.setText(settings.getValue('hotReloadExtraPath'))
        formLayout.addRow('&Hot Reload Extra Path:', self.hotReloadExtraPathField)

        self.hotReloadExtraPackageField = qtw.QLineEdit()
        self.hotReloadExtraPackageField.setText(settings.getValue('hotReloadExtraPackage'))
        formLayout.addRow('&Hot Reload Extra Package:', self.hotReloadExtraPackageField)

        saveBtn = qtw.QPushButton()
        saveBtn.setText('Save')
        saveBtn.clicked.connect(self.saveSettings)
        mainLayout.addWidget(saveBtn)

    def saveSettings(self):
        """Save the settings."""
        settings.setValue('hotReloadExtraPath', self.hotReloadExtraPathField.text())
        settings.setValue('hotReloadExtraPackage', self.hotReloadExtraPackageField.text())

        self.close()
